================================
 Zenodo-AccessRequests v1.0.0a2
================================

Zenodo-AccessRequests v1.0.0a2 was released on November 24, 2016.

About
-----

Zenodo module for providing access request feature.

What's new
----------

- Initial public release.

Installation
------------

   $ pip install zenodo-accessrequests==1.0.0a2

Documentation
-------------

   http://pythonhosted.org/zenodo-accessrequests/

Happy hacking and thanks for flying Zenodo-AccessRequests.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/zenodo/zenodo-accessrequests
|   URL: http://invenio-software.org
